@@ -1,33 +1,33 @@
 pub mod admin_cancel_task;
 pub mod admin_create_task;
+pub mod admin_initialize;
 pub mod admin_reset_health;
-pub mod config_update_admin;
-pub mod config_update_min_recurr;
-pub mod config_update_program_fee;
-pub mod config_update_worker_fee;
+pub mod admin_update_admin;
+pub mod admin_update_min_recurr;
+pub mod admin_update_program_fee;
+pub mod admin_update_worker_fee;
 pub mod daemon_create;
 pub mod daemon_invoke;
 pub mod daemon_widthdraw;
 pub mod fee_collect;
 pub mod health_check;
-pub mod initialize;
 pub mod task_cancel;
 pub mod task_create;
 pub mod task_execute;
 
 pub use admin_cancel_task::*;
 pub use admin_create_task::*;
+pub use admin_initialize::*;
 pub use admin_reset_health::*;
-pub use config_update_admin::*;
-pub use config_update_min_recurr::*;
-pub use config_update_program_fee::*;
-pub use config_update_worker_fee::*;
+pub use admin_update_admin::*;
+pub use admin_update_min_recurr::*;
+pub use admin_update_program_fee::*;
+pub use admin_update_worker_fee::*;
 pub use daemon_create::*;
 pub use daemon_invoke::*;
 pub use daemon_widthdraw::*;
 pub use fee_collect::*;
 pub use health_check::*;
-pub use initialize::*;
 pub use task_cancel::*;
 pub use task_create::*;
 pub use task_execute::*;
